<?php
/**
 * A command class for the registration form
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class HtmlRegisterCommand extends BaseCommand implements Commandable, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance	An instance of a command resolver class
	 * @return	$commandInstance	An instance a prepared command class
	 */
	public static final function createWebRegisterCommand (CommandResolver $resolverInstance) {
		// Get new instance
		$commandInstance = new WebRegisterCommand();

		// Set the application instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the given command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Set request instance as extra instance
		Registry::getRegistry()->addInstance('extra', $this);

		// Get the application instance
		$applicationInstance = $this->getResolverInstance()->getApplicationInstance();

		// Prepare a template instance
		$templateInstance = $this->prepareTemplateInstance($applicationInstance);

		// Assign all the application's data with template variables
		$templateInstance->assignApplicationData($applicationInstance);

		// Assign base URL
		$templateInstance->assignConfigVariable('base_url');

		// Load the master template
		$masterTemplate = $applicationInstance->buildMasterTemplateName();

		// Load header template
		$templateInstance->loadCodeTemplate('header');

		// Compile and assign it with a variable
		$templateInstance->compileTemplate();
		$templateInstance->assignTemplateWithVariable('header', 'header');

		// Load footer template
		$templateInstance->loadCodeTemplate('footer');

		// Compile and assign it with a variable
		$templateInstance->compileTemplate();
		$templateInstance->assignTemplateWithVariable('footer', 'footer');

		// Load the register template
		$templateInstance->loadCodeTemplate('register_form');

		// Assign the register template with the master template as a content ... ;)
		$templateInstance->compileTemplate();
		$templateInstance->assignTemplateWithVariable('register_form', 'content');

		// Load the master template
		$templateInstance->loadCodeTemplate($masterTemplate);

		// Set title
		$templateInstance->assignVariable('title', $this->getLanguageInstance()->getMessage('page_register_title'));

		// Construct the menu in every command. We could do this in BaseCommand class. But this means
		// *every* command has a navigation system and that is want we don't want.
		$menuInstance = ObjectFactory::createObjectByConfiguredName('register_menu_class', array($applicationInstance));

		// Render the menu
		$menuInstance->renderMenu();

		// Transfer it to the template engine instance
		$menuInstance->transferContentToTemplateEngine($templateInstance);

		/*
		 * ... and all variables. This should be merged together in a pattern
		 * to make things easier. A cache mechanism should be added between
		 * these two calls to cache compiled templates.
		 */
		$templateInstance->compileVariables();

		// Get the content back from the template engine and put it in response class
		$templateInstance->transferToResponse($responseInstance);
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Empty method
	}
}

// [EOF]
?>
